@@ -10,18 +10,18 @@
 
 #include <config-runtime.h>
 
-#include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/types.h>
 #include <sys/utsname.h>
 
 #include <arpa/inet.h>
 #include <netdb.h>
 
-#include <QFile>
-#include <QDir>
-#include <QDebug>
-#include <QHostInfo>
 #include <QCoreApplication>
+#include <QDebug>
+#include <QDir>
+#include <QFile>
+#include <QHostInfo>
 
 #include <KLocalizedString>
 #include <KSharedConfig>
@@ -40,9 +40,9 @@ class KIOPluginForMetaData : public QObject
     Q_PLUGIN_METADATA(IID "org.kde.kio.slave.nfs" FILE "nfs.json")
 };
 
-extern "C" int Q_DECL_EXPORT kdemain(int argc, char** argv);
+extern "C" int Q_DECL_EXPORT kdemain(int argc, char **argv);
 
-int kdemain(int argc, char** argv)
+int kdemain(int argc, char **argv)
 {
     QCoreApplication app(argc, argv);
     app.setApplicationName(QLatin1String("kio_nfs"));
@@ -58,7 +58,6 @@ int kdemain(int argc, char** argv)
     return 0;
 }
 
-
 // Both the insertion and lookup in the file handle cache (managed by
 // NFSProtocol), and the use of QFileInfo to locate a parent directory,
 // are sensitive to paths having trailing slashes.  In order to keep
@@ -67,15 +66,14 @@ int kdemain(int argc, char** argv)
 
 static QUrl cleanPath(const QUrl &url)
 {
-    return (url.adjusted(QUrl::StripTrailingSlash|QUrl::NormalizePathSegments));
+    return (url.adjusted(QUrl::StripTrailingSlash | QUrl::NormalizePathSegments));
 }
 
-
-NFSSlave::NFSSlave(const QByteArray& pool, const QByteArray& app)
-    :  KIO::SlaveBase("nfs", pool, app),
-       m_protocol(nullptr),
-       m_usedirplus3(true),
-       m_errorId(KIO::Error(0))
+NFSSlave::NFSSlave(const QByteArray &pool, const QByteArray &app)
+    : KIO::SlaveBase("nfs", pool, app)
+    , m_protocol(nullptr)
+    , m_usedirplus3(true)
+    , m_errorId(KIO::Error(0))
 {
     qCDebug(LOG_KIO_NFS) << pool << app;
 }
@@ -89,28 +87,27 @@ void NFSSlave::openConnection()
 {
     qCDebug(LOG_KIO_NFS);
 
-    if (m_protocol != nullptr)
-    {
+    if (m_protocol != nullptr) {
         m_protocol->openConnection();
         return;
     }
 
     const KSharedConfig::Ptr cfg = KSharedConfig::openConfig("kionfsrc");
 
-    const KConfigGroup grp1 = cfg->group("Default");        // default for all hosts
-    int minproto = grp1.readEntry("minproto", 2);       // minimum NFS version to accept
-    int maxproto = grp1.readEntry("maxproto", 4);       // maximum NFS version to try
-    m_usedirplus3 = grp1.readEntry("usedirplus3", true);    // use READDIRPLUS3 for listing
+    const KConfigGroup grp1 = cfg->group("Default"); // default for all hosts
+    int minproto = grp1.readEntry("minproto", 2); // minimum NFS version to accept
+    int maxproto = grp1.readEntry("maxproto", 4); // maximum NFS version to try
+    m_usedirplus3 = grp1.readEntry("usedirplus3", true); // use READDIRPLUS3 for listing
 
-    const KConfigGroup grp2 = cfg->group("Host "+m_host);
-    if (grp2.exists())                      // look for host-specific settings
-    {   // with default values from above
+    const KConfigGroup grp2 = cfg->group("Host " + m_host);
+    if (grp2.exists()) // look for host-specific settings
+    { // with default values from above
         minproto = grp2.readEntry("minproto", minproto);
         maxproto = grp2.readEntry("maxproto", maxproto);
         m_usedirplus3 = grp2.readEntry("usedirplus3", m_usedirplus3);
     }
 
-    minproto = qBound(2, minproto, 4);              // enforce limits
+    minproto = qBound(2, minproto, 4); // enforce limits
     maxproto = qBound(minproto, maxproto, 4);
     qCDebug(LOG_KIO_NFS) << "configuration for" << m_host;
     qCDebug(LOG_KIO_NFS) << "minproto" << minproto << "maxproto" << maxproto << "usedirplus3" << m_usedirplus3;
@@ -118,14 +115,12 @@ void NFSSlave::openConnection()
     bool connectionError = false;
 
     int version = maxproto;
-    while (version >= minproto)
-    {
+    while (version >= minproto) {
         qCDebug(LOG_KIO_NFS) << "Trying NFS version" << version;
 
         // Try to create an NFS protocol handler for that version
-        switch (version)
-        {
-        case 4:     // TODO
+        switch (version) {
+        case 4: // TODO
             qCDebug(LOG_KIO_NFS) << "NFSv4 is not supported at this time";
             break;
 
@@ -138,35 +133,33 @@ void NFSSlave::openConnection()
             break;
         }
 
-        if (m_protocol != nullptr)          // created protocol for that version
+        if (m_protocol != nullptr) // created protocol for that version
         {
-            m_protocol->setHost(m_host, m_user);    // try to make initial connection
-            if (m_protocol->isCompatible(connectionError)) break;
+            m_protocol->setHost(m_host, m_user); // try to make initial connection
+            if (m_protocol->isCompatible(connectionError))
+                break;
         }
 
-        delete m_protocol;              // no point using that protocol
-        --version;                  // try the next lower
-        m_protocol = nullptr;               // try again with new protocol
+        delete m_protocol; // no point using that protocol
+        --version; // try the next lower
+        m_protocol = nullptr; // try again with new protocol
     }
 
-    if (m_protocol == nullptr)              // failed to find a protocol
+    if (m_protocol == nullptr) // failed to find a protocol
     {
-        if (!connectionError)               // but connection was possible
+        if (!connectionError) // but connection was possible
         {
             setError(KIO::ERR_WORKER_DEFINED, i18n("Cannot find an NFS version that host '%1' supports", m_host));
-        }
-        else                        // connection failed
+        } else // connection failed
         {
             setError(KIO::ERR_CANNOT_CONNECT, m_host);
         }
-    }
-    else                        // usable protocol was created
+    } else // usable protocol was created
     {
-        m_protocol->openConnection();           // open the connection
+        m_protocol->openConnection(); // open the connection
     }
 }
 
-
 void NFSSlave::closeConnection()
 {
     qCDebug(LOG_KIO_NFS);
@@ -176,22 +169,17 @@ void NFSSlave::closeConnection()
     }
 }
 
-
-void NFSSlave::setHost(const QString& host, quint16 /*port*/, const QString &user, const QString& /*pass*/)
+void NFSSlave::setHost(const QString &host, quint16 /*port*/, const QString &user, const QString & /*pass*/)
 {
     qCDebug(LOG_KIO_NFS) << "host" << host << "user" << user;
 
-    if (m_protocol != nullptr)
-    {
+    if (m_protocol != nullptr) {
         // New host or user? New protocol!
-        if (host != m_host || user != m_user)
-        {
+        if (host != m_host || user != m_user) {
             qCDebug(LOG_KIO_NFS) << "Deleting old protocol";
             delete m_protocol;
             m_protocol = nullptr;
-        }
-        else
-        {
+        } else {
             // TODO: Doing this is pointless if nothing has changed
             m_protocol->setHost(host, user);
         }
@@ -201,8 +189,7 @@ void NFSSlave::setHost(const QString& host, quint16 /*port*/, const QString &use
     m_user = user;
 }
 
-
-void NFSSlave::put(const QUrl& url, int _mode, KIO::JobFlags _flags)
+void NFSSlave::put(const QUrl &url, int _mode, KIO::JobFlags _flags)
 {
     qCDebug(LOG_KIO_NFS);
 
@@ -212,7 +199,7 @@ void NFSSlave::put(const QUrl& url, int _mode, KIO::JobFlags _flags)
     finishOperation();
 }
 
-void NFSSlave::get(const QUrl& url)
+void NFSSlave::get(const QUrl &url)
 {
     qCDebug(LOG_KIO_NFS);
 
@@ -222,7 +209,7 @@ void NFSSlave::get(const QUrl& url)
     finishOperation();
 }
 
-void NFSSlave::listDir(const QUrl& url)
+void NFSSlave::listDir(const QUrl &url)
 {
     qCDebug(LOG_KIO_NFS) << url;
 
@@ -232,7 +219,7 @@ void NFSSlave::listDir(const QUrl& url)
     finishOperation();
 }
 
-void NFSSlave::symlink(const QString& target, const QUrl& dest, KIO::JobFlags _flags)
+void NFSSlave::symlink(const QString &target, const QUrl &dest, KIO::JobFlags _flags)
 {
     qCDebug(LOG_KIO_NFS);
 
@@ -242,7 +229,7 @@ void NFSSlave::symlink(const QString& target, const QUrl& dest, KIO::JobFlags _f
     finishOperation();
 }
 
-void NFSSlave::stat(const QUrl& url)
+void NFSSlave::stat(const QUrl &url)
 {
     qCDebug(LOG_KIO_NFS);
 
@@ -252,7 +239,7 @@ void NFSSlave::stat(const QUrl& url)
     finishOperation();
 }
 
-void NFSSlave::mkdir(const QUrl& url, int permissions)
+void NFSSlave::mkdir(const QUrl &url, int permissions)
 {
     qCDebug(LOG_KIO_NFS);
 
@@ -262,7 +249,7 @@ void NFSSlave::mkdir(const QUrl& url, int permissions)
     finishOperation();
 }
 
-void NFSSlave::del(const QUrl& url, bool isfile)
+void NFSSlave::del(const QUrl &url, bool isfile)
 {
     qCDebug(LOG_KIO_NFS);
 
@@ -272,7 +259,7 @@ void NFSSlave::del(const QUrl& url, bool isfile)
     finishOperation();
 }
 
-void NFSSlave::chmod(const QUrl& url, int permissions)
+void NFSSlave::chmod(const QUrl &url, int permissions)
 {
     qCDebug(LOG_KIO_NFS);
 
@@ -282,7 +269,7 @@ void NFSSlave::chmod(const QUrl& url, int permissions)
     finishOperation();
 }
 
-void NFSSlave::rename(const QUrl& src, const QUrl& dest, KIO::JobFlags flags)
+void NFSSlave::rename(const QUrl &src, const QUrl &dest, KIO::JobFlags flags)
 {
     qCDebug(LOG_KIO_NFS);
 
@@ -292,7 +279,7 @@ void NFSSlave::rename(const QUrl& src, const QUrl& dest, KIO::JobFlags flags)
     finishOperation();
 }
 
-void NFSSlave::copy(const QUrl& src, const QUrl& dest, int mode, KIO::JobFlags flags)
+void NFSSlave::copy(const QUrl &src, const QUrl &dest, int mode, KIO::JobFlags flags)
 {
     qCDebug(LOG_KIO_NFS);
 
@@ -302,21 +289,21 @@ void NFSSlave::copy(const QUrl& src, const QUrl& dest, int mode, KIO::JobFlags f
     finishOperation();
 }
 
-
 // Perform initial URL and host checks before starting any operation.
 // This means any KIO::SlaveBase action which is expected to end by
 // calling either error() or finished().
 bool NFSSlave::verifyProtocol(const QUrl &url)
 {
-    m_errorId = KIO::Error(0);              // ensure reset before starting
+    m_errorId = KIO::Error(0); // ensure reset before starting
     m_errorText.clear();
 
     // The NFS protocol definition includes copyToFile=true and copyFromFile=true,
     // so the URL scheme here can also be "file".  No URL or protocol checking
     // is required in this case.
-    if (url.scheme() != "nfs") return true;
+    if (url.scheme() != "nfs")
+        return true;
 
-    if (!url.isValid())                 // also checks for empty
+    if (!url.isValid()) // also checks for empty
     {
         setError(KIO::ERR_MALFORMED_URL, url.toDisplayString());
         return (false);
@@ -328,49 +315,44 @@ bool NFSSlave::verifyProtocol(const QUrl &url)
     // in NFSSlave::openConnection().
 
     const QString host = url.host();
-    if (host.isEmpty())
-    {
+    if (host.isEmpty()) {
         // KIO::ERR_UNKNOWN_HOST with a blank host name results in the
         // error message "No hostname specified", but Konqueror does not
         // report it properly.  Return our own message.
         setError(KIO::ERR_WORKER_DEFINED, i18n("The NFS protocol requires a server host name."));
         return (false);
-    }
-    else
-    {
+    } else {
         // There is a host name, so check that it can be resolved.  If it
         // can't, return an error now and don't bother trying the protocol.
         QHostInfo hostInfo = QHostInfo::fromName(host);
-        if (hostInfo.error() != QHostInfo::NoError)
-        {
+        if (hostInfo.error() != QHostInfo::NoError) {
             qCDebug(LOG_KIO_NFS) << "host lookup of" << host << "error" << hostInfo.errorString();
             setError(KIO::ERR_UNKNOWN_HOST, host);
             return (false);
         }
     }
 
-    if (m_protocol==nullptr)                // no protocol connection yet
+    if (m_protocol == nullptr) // no protocol connection yet
     {
-        openConnection();               // create and open connection
-        if (m_protocol==nullptr)            // if that failed, then
-        {   // no more can be done
+        openConnection(); // create and open connection
+        if (m_protocol == nullptr) // if that failed, then
+        { // no more can be done
             qCDebug(LOG_KIO_NFS) << "Could not resolve a compatible protocol version!";
             goto fail;
         }
-    }
-    else if (!m_protocol->isConnected())        // already have a protocol
+    } else if (!m_protocol->isConnected()) // already have a protocol
     {
-        m_protocol->openConnection();           // open its connection
+        m_protocol->openConnection(); // open its connection
     }
 
-    if (m_protocol->isConnected()) return true;     // connection succeeded
+    if (m_protocol->isConnected())
+        return true; // connection succeeded
 
-fail:                           // default error if none already
+fail: // default error if none already
     setError(KIO::ERR_INTERNAL, i18n("Failed to initialise protocol"));
     return false;
 }
 
-
 // These two functions keep track of errors found during any operation,
 // and return the error or finish the operation appropriately when
 // the operation is complete.
@@ -385,8 +367,7 @@ fail:                           // default error if none already
 
 void NFSSlave::setError(KIO::Error errid, const QString &text)
 {
-    if (m_errorId!=0)
-    {
+    if (m_errorId != 0) {
         qCDebug(LOG_KIO_NFS) << errid << "ignored due to previous error";
         return;
     }
@@ -396,53 +377,51 @@ void NFSSlave::setError(KIO::Error errid, const QString &text)
     m_errorText = text;
 }
 
-
 // An operation is complete.  If there has been an error, then report it.
 void NFSSlave::finishOperation()
 {
-    if (m_errorId==0) {                 // no error encountered
+    if (m_errorId == 0) { // no error encountered
         SlaveBase::finished();
-    } else {                        // there was an error
+    } else { // there was an error
         SlaveBase::error(m_errorId, m_errorText);
     }
 }
 
-
 NFSFileHandle::NFSFileHandle()
-    : m_handle(nullptr),
-      m_size(0),
-      m_linkHandle(nullptr),
-      m_linkSize(0),
-      m_isLink(false)
+    : m_handle(nullptr)
+    , m_size(0)
+    , m_linkHandle(nullptr)
+    , m_linkSize(0)
+    , m_isLink(false)
 {
 }
 
-NFSFileHandle::NFSFileHandle(const NFSFileHandle& src)
-    :  NFSFileHandle()
+NFSFileHandle::NFSFileHandle(const NFSFileHandle &src)
+    : NFSFileHandle()
 {
     (*this) = src;
 }
 
-NFSFileHandle::NFSFileHandle(const fhandle3& src)
-    :  NFSFileHandle()
+NFSFileHandle::NFSFileHandle(const fhandle3 &src)
+    : NFSFileHandle()
 {
     (*this) = src;
 }
 
-NFSFileHandle::NFSFileHandle(const fhandle& src)
-    :  NFSFileHandle()
+NFSFileHandle::NFSFileHandle(const fhandle &src)
+    : NFSFileHandle()
 {
     (*this) = src;
 }
 
-NFSFileHandle::NFSFileHandle(const nfs_fh3& src)
-    :  NFSFileHandle()
+NFSFileHandle::NFSFileHandle(const nfs_fh3 &src)
+    : NFSFileHandle()
 {
     (*this) = src;
 }
 
-NFSFileHandle::NFSFileHandle(const nfs_fh& src)
-    :  NFSFileHandle()
+NFSFileHandle::NFSFileHandle(const nfs_fh &src)
+    : NFSFileHandle()
 {
     (*this) = src;
 }
@@ -450,40 +429,40 @@ NFSFileHandle::NFSFileHandle(const nfs_fh& src)
 NFSFileHandle::~NFSFileHandle()
 {
     if (m_handle != nullptr) {
-        delete [] m_handle;
+        delete[] m_handle;
     }
     if (m_linkHandle != nullptr) {
-        delete [] m_linkHandle;
+        delete[] m_linkHandle;
     }
 }
 
-void NFSFileHandle::toFH(nfs_fh3& fh) const
+void NFSFileHandle::toFH(nfs_fh3 &fh) const
 {
     fh.data.data_len = m_size;
     fh.data.data_val = m_handle;
 }
 
-void NFSFileHandle::toFH(nfs_fh& fh) const
+void NFSFileHandle::toFH(nfs_fh &fh) const
 {
     memcpy(fh.data, m_handle, m_size);
 }
 
-void NFSFileHandle::toFHLink(nfs_fh3& fh) const
+void NFSFileHandle::toFHLink(nfs_fh3 &fh) const
 {
     fh.data.data_len = m_linkSize;
     fh.data.data_val = m_linkHandle;
 }
 
-void NFSFileHandle::toFHLink(nfs_fh& fh) const
+void NFSFileHandle::toFHLink(nfs_fh &fh) const
 {
     memcpy(fh.data, m_linkHandle, m_size);
 }
 
-NFSFileHandle& NFSFileHandle::operator=(const NFSFileHandle& src)
+NFSFileHandle &NFSFileHandle::operator=(const NFSFileHandle &src)
 {
     if (src.m_size > 0) {
         if (m_handle != nullptr) {
-            delete [] m_handle;
+            delete[] m_handle;
             m_handle = nullptr;
         }
         m_size = src.m_size;
@@ -492,7 +471,7 @@ NFSFileHandle& NFSFileHandle::operator=(const NFSFileHandle& src)
     }
     if (src.m_linkSize > 0) {
         if (m_linkHandle != nullptr) {
-            delete [] m_linkHandle;
+            delete[] m_linkHandle;
             m_linkHandle = nullptr;
         }
 
@@ -505,10 +484,10 @@ NFSFileHandle& NFSFileHandle::operator=(const NFSFileHandle& src)
     return *this;
 }
 
-NFSFileHandle& NFSFileHandle::operator=(const fhandle3& src)
+NFSFileHandle &NFSFileHandle::operator=(const fhandle3 &src)
 {
     if (m_handle != nullptr) {
-        delete [] m_handle;
+        delete[] m_handle;
         m_handle = nullptr;
     }
 
@@ -518,10 +497,10 @@ NFSFileHandle& NFSFileHandle::operator=(const fhandle3& src)
     return *this;
 }
 
-NFSFileHandle& NFSFileHandle::operator=(const fhandle& src)
+NFSFileHandle &NFSFileHandle::operator=(const fhandle &src)
 {
     if (m_handle != nullptr) {
-        delete [] m_handle;
+        delete[] m_handle;
         m_handle = nullptr;
     }
 
@@ -531,10 +510,10 @@ NFSFileHandle& NFSFileHandle::operator=(const fhandle& src)
     return *this;
 }
 
-NFSFileHandle& NFSFileHandle::operator=(const nfs_fh3& src)
+NFSFileHandle &NFSFileHandle::operator=(const nfs_fh3 &src)
 {
     if (m_handle != nullptr) {
-        delete [] m_handle;
+        delete[] m_handle;
         m_handle = nullptr;
     }
 
@@ -544,10 +523,10 @@ NFSFileHandle& NFSFileHandle::operator=(const nfs_fh3& src)
     return *this;
 }
 
-NFSFileHandle& NFSFileHandle::operator=(const nfs_fh& src)
+NFSFileHandle &NFSFileHandle::operator=(const nfs_fh &src)
 {
     if (m_handle != nullptr) {
-        delete [] m_handle;
+        delete[] m_handle;
         m_handle = nullptr;
     }
 
@@ -557,10 +536,10 @@ NFSFileHandle& NFSFileHandle::operator=(const nfs_fh& src)
     return *this;
 }
 
-void NFSFileHandle::setLinkSource(const nfs_fh3& src)
+void NFSFileHandle::setLinkSource(const nfs_fh3 &src)
 {
     if (m_linkHandle != nullptr) {
-        delete [] m_linkHandle;
+        delete[] m_linkHandle;
         m_linkHandle = nullptr;
     }
 
@@ -570,10 +549,10 @@ void NFSFileHandle::setLinkSource(const nfs_fh3& src)
     m_isLink = true;
 }
 
-void NFSFileHandle::setLinkSource(const nfs_fh& src)
+void NFSFileHandle::setLinkSource(const nfs_fh &src)
 {
     if (m_linkHandle != nullptr) {
-        delete [] m_linkHandle;
+        delete[] m_linkHandle;
         m_linkHandle = nullptr;
     }
 
@@ -583,12 +562,12 @@ void NFSFileHandle::setLinkSource(const nfs_fh& src)
     m_isLink = true;
 }
 
-NFSProtocol::NFSProtocol(NFSSlave* slave)
+NFSProtocol::NFSProtocol(NFSSlave *slave)
     : m_slave(slave)
 {
 }
 
-void NFSProtocol::copy(const QUrl& src, const QUrl& dest, int mode, KIO::JobFlags flags)
+void NFSProtocol::copy(const QUrl &src, const QUrl &dest, int mode, KIO::JobFlags flags)
 {
     if (src.isLocalFile()) {
         copyTo(src, dest, mode, flags);
@@ -599,18 +578,17 @@ void NFSProtocol::copy(const QUrl& src, const QUrl& dest, int mode, KIO::JobFlag
     }
 }
 
-void NFSProtocol::addExportedDir(const QString& path)
+void NFSProtocol::addExportedDir(const QString &path)
 {
     m_exportedDirs.append(path);
 }
 
-const QStringList& NFSProtocol::getExportedDirs()
+const QStringList &NFSProtocol::getExportedDirs()
 {
     return m_exportedDirs;
 }
 
-
-bool NFSProtocol::isExportedDir(const QString& path)
+bool NFSProtocol::isExportedDir(const QString &path)
 {
     // See whether the path is an exported directory:  that is, a prefix
     // of but not identical to any of the server exports.  If it is, then
@@ -626,20 +604,17 @@ bool NFSProtocol::isExportedDir(const QString& path)
     // to or a prefix of the given path".
 
     // The root is always considered to be exported.
-    if (path.isEmpty() || path == "/" || QFileInfo(path).isRoot())
-    {
+    if (path.isEmpty() || path == "/" || QFileInfo(path).isRoot()) {
         qCDebug(LOG_KIO_NFS) << path << "is root";
         return true;
     }
 
-    const QString dirPath = path+QDir::separator();
-    for (QStringList::const_iterator it = m_exportedDirs.constBegin();
-            it != m_exportedDirs.constEnd(); ++it) {
+    const QString dirPath = path + QDir::separator();
+    for (QStringList::const_iterator it = m_exportedDirs.constBegin(); it != m_exportedDirs.constEnd(); ++it) {
         const QString &exportedDir = (*it);
         // We know that both 'path' and the contents of m_exportedDirs
         // have been cleaned of any trailing slashes.
-        if (exportedDir.startsWith(dirPath))
-        {
+        if (exportedDir.startsWith(dirPath)) {
             qCDebug(LOG_KIO_NFS) << path << "is exported";
             return true;
         }
@@ -648,26 +623,26 @@ bool NFSProtocol::isExportedDir(const QString& path)
     return false;
 }
 
-
-void NFSProtocol::removeExportedDir(const QString& path)
+void NFSProtocol::removeExportedDir(const QString &path)
 {
     m_exportedDirs.removeOne(path);
 }
 
-void NFSProtocol::addFileHandle(const QString& path, NFSFileHandle fh)
+void NFSProtocol::addFileHandle(const QString &path, NFSFileHandle fh)
 {
-    if (fh.isInvalid()) qCDebug(LOG_KIO_NFS) << "not adding" << path << "with invalid NFSFileHandle";
-    else m_handleCache.insert(path, fh);
+    if (fh.isInvalid())
+        qCDebug(LOG_KIO_NFS) << "not adding" << path << "with invalid NFSFileHandle";
+    else
+        m_handleCache.insert(path, fh);
 }
 
-NFSFileHandle NFSProtocol::getFileHandle(const QString& path)
+NFSFileHandle NFSProtocol::getFileHandle(const QString &path)
 {
     if (!isConnected()) {
         return NFSFileHandle();
     }
 
-    if (m_exportedDirs.contains(path))
-    {
+    if (m_exportedDirs.contains(path)) {
         // All exported directories should have already been stored in
         // m_handleCache by the protocol's openConnection().  If any
         // exported directory could not be mounted, then it will be in
@@ -713,13 +688,12 @@ NFSFileHandle NFSProtocol::getFileHandle(const QString& path)
     return childFH;
 }
 
-void NFSProtocol::removeFileHandle(const QString& path)
+void NFSProtocol::removeFileHandle(const QString &path)
 {
     m_handleCache.remove(path);
 }
 
-
-bool NFSProtocol::isValidPath(const QString& path)
+bool NFSProtocol::isValidPath(const QString &path)
 {
     // See whether the path is or below an exported directory:
     // that is, any of the server exports is identical to or a prefix
@@ -733,30 +707,29 @@ bool NFSProtocol::isValidPath(const QString& path)
     // directory".
 
     // The root is always considered to be valid.
-    if (path.isEmpty() || path == "/" || QFileInfo(path).isRoot())
-    {
+    if (path.isEmpty() || path == "/" || QFileInfo(path).isRoot()) {
         return true;
     }
 
-    for (QStringList::const_iterator it = m_exportedDirs.constBegin();
-            it != m_exportedDirs.constEnd(); ++it)
-    {
+    for (QStringList::const_iterator it = m_exportedDirs.constBegin(); it != m_exportedDirs.constEnd(); ++it) {
         const QString &exportedDir = (*it);
         // We know that both 'path' and the contents of m_exportedDirs
         // have been cleaned of any trailing slashes.
-        if (path == exportedDir) return true;
-        if (path.startsWith(exportedDir+QDir::separator())) return true;
+        if (path == exportedDir)
+            return true;
+        if (path.startsWith(exportedDir + QDir::separator()))
+            return true;
     }
 
     return false;
 }
 
-
 bool NFSProtocol::isValidLink(const QString &parentDir, const QString &linkDest)
 {
     qCDebug(LOG_KIO_NFS) << "checking" << linkDest << "in" << parentDir;
 
-    if (linkDest.isEmpty()) return false;       // ensure link is absolute
+    if (linkDest.isEmpty())
+        return false; // ensure link is absolute
     const QString absDest = QFileInfo(parentDir, linkDest).absoluteFilePath();
 
     // The link target may not be valid on the NFS server (i.e. it may
@@ -766,8 +739,7 @@ bool NFSProtocol::isValidLink(const QString &parentDir, const QString &linkDest)
     // ERR_CANNOT_ENTER_DIRECTORY which will be taken as the result of
     // the NFS operation.  This is not an error condition if just checking
     // the target of a link, so do the same check here but ignore any error.
-    if (!isValidPath(absDest))
-    {
+    if (!isValidPath(absDest)) {
         qCDebug(LOG_KIO_NFS) << "target" << absDest << "is invalid";
         return false;
     }
@@ -776,8 +748,7 @@ bool NFSProtocol::isValidLink(const QString &parentDir, const QString &linkDest)
     return (!getFileHandle(absDest).isInvalid());
 }
 
-
-KIO::Error NFSProtocol::openConnection(const QString& host, int prog, int vers, CLIENT*& client, int& sock)
+KIO::Error NFSProtocol::openConnection(const QString &host, int prog, int vers, CLIENT *&client, int &sock)
 {
     // NFSSlave::verifyProtocol() should already have checked that
     // the host name is not blank and is resolveable, so the two
@@ -792,7 +763,7 @@ KIO::Error NFSProtocol::openConnection(const QString& host, int prog, int vers,
         server_addr.sin_family = AF_INET;
         server_addr.sin_addr.s_addr = inet_addr(host.toLatin1().constData());
     } else {
-        struct hostent* hp = gethostbyname(host.toLatin1().constData());
+        struct hostent *hp = gethostbyname(host.toLatin1().constData());
         if (hp == nullptr) {
             return KIO::ERR_UNKNOWN_HOST;
         }
@@ -825,15 +796,15 @@ KIO::Error NFSProtocol::openConnection(const QString& host, int prog, int vers,
     }
 
     uid_t uid = geteuid();
-    if (!m_currentUser.isEmpty())
-    {
+    if (!m_currentUser.isEmpty()) {
         bool ok;
         uid_t num = m_currentUser.toUInt(&ok);
-        if (ok) uid = num;
-        else
-        {
+        if (ok)
+            uid = num;
+        else {
             const struct passwd *pwd = getpwnam(m_currentUser.toLocal8Bit().constData());
-            if (pwd != nullptr) uid = pwd->pw_uid;
+            if (pwd != nullptr)
+                uid = pwd->pw_uid;
         }
     }
 
@@ -841,20 +812,16 @@ KIO::Error NFSProtocol::openConnection(const QString& host, int prog, int vers,
     return KIO::Error(0);
 }
 
-
-bool NFSProtocol::checkForError(int clientStat, int nfsStat, const QString& text)
+bool NFSProtocol::checkForError(int clientStat, int nfsStat, const QString &text)
 {
-    if (clientStat!=RPC_SUCCESS)
-    {
+    if (clientStat != RPC_SUCCESS) {
         const char *errstr = clnt_sperrno(static_cast<clnt_stat>(clientStat));
         qCDebug(LOG_KIO_NFS) << "RPC error" << clientStat << errstr << "on" << text;
-        m_slave->setError(KIO::ERR_INTERNAL_SERVER,
-                          i18n("RPC error %1, %2", QString::number(clientStat), errstr));
+        m_slave->setError(KIO::ERR_INTERNAL_SERVER, i18n("RPC error %1, %2", QString::number(clientStat), errstr));
         return false;
     }
 
-    if (nfsStat != NFS_OK)
-    {
+    if (nfsStat != NFS_OK) {
         qCDebug(LOG_KIO_NFS) << "NFS error" << nfsStat << text;
         switch (nfsStat) {
         case NFSERR_PERM:
@@ -863,11 +830,11 @@ bool NFSProtocol::checkForError(int clientStat, int nfsStat, const QString& text
         case NFSERR_NOENT:
             m_slave->setError(KIO::ERR_DOES_NOT_EXIST, text);
             break;
-        //does this mapping make sense ?
+        // does this mapping make sense ?
         case NFSERR_IO:
             m_slave->setError(KIO::ERR_INTERNAL_SERVER, text);
             break;
-        //does this mapping make sense ?
+        // does this mapping make sense ?
         case NFSERR_NXIO:
             m_slave->setError(KIO::ERR_DOES_NOT_EXIST, text);
             break;
@@ -877,7 +844,7 @@ bool NFSProtocol::checkForError(int clientStat, int nfsStat, const QString& text
         case NFSERR_EXIST:
             m_slave->setError(KIO::ERR_FILE_ALREADY_EXIST, text);
             break;
-        //does this mapping make sense ?
+        // does this mapping make sense ?
         case NFSERR_NODEV:
             m_slave->setError(KIO::ERR_DOES_NOT_EXIST, text);
             break;
@@ -887,11 +854,11 @@ bool NFSProtocol::checkForError(int clientStat, int nfsStat, const QString& text
         case NFSERR_ISDIR:
             m_slave->setError(KIO::ERR_IS_DIRECTORY, text);
             break;
-        //does this mapping make sense ?
+        // does this mapping make sense ?
         case NFSERR_FBIG:
             m_slave->setError(KIO::ERR_INTERNAL_SERVER, text);
             break;
-        //does this mapping make sense ?
+        // does this mapping make sense ?
         case NFSERR_NOSPC:
             m_slave->setError(KIO::ERR_DISK_FULL, text);
             break;
@@ -904,7 +871,7 @@ bool NFSProtocol::checkForError(int clientStat, int nfsStat, const QString& text
         case NFSERR_NOTEMPTY:
             m_slave->setError(KIO::ERR_CANNOT_RMDIR, text);
             break;
-        //does this mapping make sense ?
+        // does this mapping make sense ?
         case NFSERR_DQUOT:
             m_slave->setError(KIO::ERR_INTERNAL_SERVER, i18n("Disk quota exceeded"));
             break;
@@ -920,7 +887,6 @@ bool NFSProtocol::checkForError(int clientStat, int nfsStat, const QString& text
     return true;
 }
 
-
 // Perform checks and, if so indicated, list a virtual (exported)
 // directory that will not actually involve accessing the NFS server.
 // Return the directory path, or a null string if there is a problem
@@ -932,30 +898,31 @@ QString NFSProtocol::listDirInternal(const QUrl &url)
 
     const QString path(url.path());
     // Is the path part of an exported (virtual) directory?
-    if (isExportedDir(path))
-    {
+    if (isExportedDir(path)) {
         qCDebug(LOG_KIO_NFS) << "Listing virtual dir" << path;
 
         QString dirPrefix = path;
-        if (dirPrefix!="/") dirPrefix += QDir::separator();
+        if (dirPrefix != "/")
+            dirPrefix += QDir::separator();
 
         QStringList virtualList;
         const QStringList exportedDirs = getExportedDirs();
-        for (QStringList::const_iterator it = exportedDirs.constBegin(); it != exportedDirs.constEnd(); ++it)
-        {
+        for (QStringList::const_iterator it = exportedDirs.constBegin(); it != exportedDirs.constEnd(); ++it) {
             // When an export is multiple levels deep (for example "/export/nfs/dir"
             // where "/export" is being listed), we only want to display one level
             // ("nfs") at a time.  Find all of the exported directories that are
             // below the 'dirPrefix', and list the first (or only) path component
             // of each.
 
-            QString name = (*it);           // this exported directory
-            if (!name.startsWith(dirPrefix)) continue;  // not below this prefix
+            QString name = (*it); // this exported directory
+            if (!name.startsWith(dirPrefix))
+                continue; // not below this prefix
 
-            name = name.mid(dirPrefix.length());    // remainder after the prefix
+            name = name.mid(dirPrefix.length()); // remainder after the prefix
 
             const int idx = name.indexOf(QDir::separator());
-            if (idx!=-1) name = name.left(idx);     // take first path component
+            if (idx != -1)
+                name = name.left(idx); // take first path component
 
             if (!virtualList.contains(name)) {
                 qCDebug(LOG_KIO_NFS) << "Found exported" << name;
@@ -969,28 +936,29 @@ QString NFSProtocol::listDirInternal(const QUrl &url)
         entry.fastInsert(KIO::UDSEntry::UDS_ICON_NAME, "folder-network");
         m_slave->listEntry(entry);
 
-        for (QStringList::const_iterator it = virtualList.constBegin(); it != virtualList.constEnd(); ++it)
-        {
-            const QString &name = (*it);        // this listed directory
+        for (QStringList::const_iterator it = virtualList.constBegin(); it != virtualList.constEnd(); ++it) {
+            const QString &name = (*it); // this listed directory
 
             entry.replace(KIO::UDSEntry::UDS_NAME, name);
-            if (isExportedDir(dirPrefix+name)) entry.replace(KIO::UDSEntry::UDS_ICON_NAME, "folder-network");
-            else entry.replace(KIO::UDSEntry::UDS_ICON_NAME, "folder");
+            if (isExportedDir(dirPrefix + name))
+                entry.replace(KIO::UDSEntry::UDS_ICON_NAME, "folder-network");
+            else
+                entry.replace(KIO::UDSEntry::UDS_ICON_NAME, "folder");
 
             m_slave->listEntry(entry);
         }
 
-        return (QString());             // listed, no more to do
+        return (QString()); // listed, no more to do
     }
 
     // For the listing we now actually need to access the NFS server.
     // We should always be connected at this point, but better safe than sorry!
-    if (!isConnected()) return (QString());
+    if (!isConnected())
+        return (QString());
 
-    return (path);                  // the path to list
+    return (path); // the path to list
 }
 
-
 // Perform checks and, if so indicated, return information for
 // a virtual (exported) directory.  Return the entry path, or a
 // null string if there is a problem or if the URL refers to a
@@ -1001,8 +969,7 @@ QString NFSProtocol::statInternal(const QUrl &url)
     qCDebug(LOG_KIO_NFS) << url;
 
     const QString path(url.path());
-    if (path.isEmpty())
-    {
+    if (path.isEmpty()) {
         // Displaying a location with an empty path (e.g. "nfs://server")
         // seems to confuse Konqueror, it shows the directory but will not
         // descend into any subdirectories.  The same location with a root
@@ -1015,8 +982,7 @@ QString NFSProtocol::statInternal(const QUrl &url)
 
     // We can't stat an exported directory on the NFS server,
     // but we know that it must be a directory.
-    if (isExportedDir(path))
-    {
+    if (isExportedDir(path)) {
         KIO::UDSEntry entry;
         entry.fastInsert(KIO::UDSEntry::UDS_NAME, ".");
         entry.fastInsert(KIO::UDSEntry::UDS_ICON_NAME, "folder-network");
@@ -1026,10 +992,9 @@ QString NFSProtocol::statInternal(const QUrl &url)
         return (QString());
     }
 
-    return (path);                  // the path to stat
+    return (path); // the path to stat
 }
 
-
 // Set the host to be accessed.  If the host has changed a new
 // host connection is required, so close the current one.
 //
@@ -1041,19 +1006,19 @@ void NFSProtocol::setHost(const QString &host, const QString &user)
 {
     qCDebug(LOG_KIO_NFS) << "host" << host << "user" << user;
 
-    if (host.isEmpty())                 // must have a host name
+    if (host.isEmpty()) // must have a host name
     {
         m_slave->setError(KIO::ERR_UNKNOWN_HOST, host);
         return;
     }
     // nothing to do if no change
-    if (host == m_currentHost && user == m_currentUser) return;
-    closeConnection();                  // close the existing connection
-    m_currentHost = host;               // set the new host name
-    m_currentUser = user;               // set the new user name
+    if (host == m_currentHost && user == m_currentUser)
+        return;
+    closeConnection(); // close the existing connection
+    m_currentHost = host; // set the new host name
+    m_currentUser = user; // set the new user name
 }
 
-
 // This function and completeInvalidUDSEntry() must use KIO::UDSEntry::replace()
 // because they may be called with a UDSEntry that has already been partially
 // filled in by NFSProtocol::createVirtualDirEntry().
@@ -1062,37 +1027,32 @@ void NFSProtocol::completeUDSEntry(KIO::UDSEntry &entry, uid_t uid, gid_t gid)
 {
     QString str;
 
-    if (!m_usercache.contains(uid))
-    {
+    if (!m_usercache.contains(uid)) {
         const struct passwd *user = getpwuid(uid);
-        if (user!=nullptr)
-        {
+        if (user != nullptr) {
             m_usercache.insert(uid, QString::fromLatin1(user->pw_name));
             str = user->pw_name;
-        }
-        else str = QString::number(uid);
-    }
-    else str = m_usercache.value(uid);
+        } else
+            str = QString::number(uid);
+    } else
+        str = m_usercache.value(uid);
     entry.replace(KIO::UDSEntry::UDS_USER, str);
 
-    if (!m_groupcache.contains(gid))
-    {
+    if (!m_groupcache.contains(gid)) {
         const struct group *grp = getgrgid(gid);
-        if (grp!=nullptr)
-        {
+        if (grp != nullptr) {
             m_groupcache.insert(gid, QString::fromLatin1(grp->gr_name));
             str = grp->gr_name;
-        }
-        else str = QString::number(gid);
-    }
-    else str = m_groupcache.value(gid);
+        } else
+            str = QString::number(gid);
+    } else
+        str = m_groupcache.value(gid);
     entry.replace(KIO::UDSEntry::UDS_GROUP, str);
 }
 
-
 void NFSProtocol::completeInvalidUDSEntry(KIO::UDSEntry &entry)
 {
-    entry.replace(KIO::UDSEntry::UDS_SIZE, 0);      // dummy size
+    entry.replace(KIO::UDSEntry::UDS_SIZE, 0); // dummy size
     entry.replace(KIO::UDSEntry::UDS_FILE_TYPE, S_IFMT - 1);
     entry.replace(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
     // The UDS_USER and UDS_GROUP must be string values.  It would be possible
@@ -1102,12 +1062,11 @@ void NFSProtocol::completeInvalidUDSEntry(KIO::UDSEntry &entry)
     entry.replace(KIO::UDSEntry::UDS_GROUP, QString::fromLatin1("root"));
 }
 
-
 // This uses KIO::UDSEntry::fastInsert() and so must only be called with
 // a blank UDSEntry or one where only UDS_NAME has been filled in.
-void NFSProtocol::createVirtualDirEntry(UDSEntry& entry)
+void NFSProtocol::createVirtualDirEntry(UDSEntry &entry)
 {
-    entry.fastInsert(KIO::UDSEntry::UDS_SIZE, 0);   // dummy size
+    entry.fastInsert(KIO::UDSEntry::UDS_SIZE, 0); // dummy size
     entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
     entry.fastInsert(KIO::UDSEntry::UDS_MIME_TYPE, "inode/directory");
     entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
